@@ -167,7 +167,7 @@ def init(host, access_token, client_id, path, project_name, workflow_id, locale,
 @ltk.command()
 #TO-DO: @click.option('-a', '--all', help='List all configuration settings (including access token)')
 @click.option('-l', '--locale', help='Change the default source locale for the project')
-@click.option('-w', '--workflow_id', help='Change the default workflow id for the project')
+@click.option('-w', '--workflow_id', is_flag=False, flag_value="project default", help='Change the workflow id for the project')
 @click.option('-ld', '--latest_document', help='Toggle always get latest document option \'on\' and \'off\'')
 @click.option('-c', '--clone_option', help='Toggle clone download option \'on\' and \'off\'. Turning clone \'on\': Translations will be downloaded to a cloned folder structure, where the root folder for each locale is the locale folder specified in config or a locale folder inside of the default download folder. If a default download folder is not set, then translations will be downloaded to the directory where the project was initialized.' +
                                                 'Turning clone \'off\': Downloaded translations will go into their locale folder (if specified) or default download folder, but not in a cloned folder structure. If no default download folder or locale folder is specified, downloaded translations will go to the same folder as their corresponding source files.')
