@@ -314,7 +314,7 @@ class ApiCalls:
         try:
             uri = (API_URI['document_translation'] % locals())
             payload = {'locale_code': locale, 'id': document_id}
-            if workflow_id:
+            if workflow_id and workflow_id != 'project default':
                 payload['workflow_id'] = workflow_id
             if due_date:
                 payload['due_date'] = due_date
@@ -365,6 +365,8 @@ class ApiCalls:
             uri = (API_URI['document_translation_locale'] % locals())
             r = requests.get(self.host + uri, headers=self.headers)
             log_api('GET', uri, r)
+            if r.status_code != 200:
+                raise RequestFailedError("Unable to get translation status")
         except requests.exceptions.ConnectionError:
             self.handleError()
         return r
